==> huaweicloudsdkdbss-3.1.135-py2.py3-none-any.whl: huaweicloudsdkdbss/v1/model/audit_sql_response_sqls.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AuditSqlResponseSqls:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sql': 'AuditSqlResponseSql'
    }

    attribute_map = {
        'sql': 'sql'
    }

    def __init__(self, sql=None):
        """AuditSqlResponseSqls

        The model defined in huaweicloud sdk

        :param sql: 
        :type sql: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        
        

        self._sql = None
        self.discriminator = None

        self.sql = sql

    @property
    def sql(self):
        """Gets the sql of this AuditSqlResponseSqls.

        :return: The sql of this AuditSqlResponseSqls.
        :rtype: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        return self._sql

    @sql.setter
    def sql(self, sql):
        """Sets the sql of this AuditSqlResponseSqls.

        :param sql: The sql of this AuditSqlResponseSqls.
        :type sql: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        self._sql = sql

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditSqlResponseSqls):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdbss-3.1.155-py2.py3-none-any.whl: huaweicloudsdkdbss/v1/model/audit_sql_response_sqls.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class AuditSqlResponseSqls:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'sql': 'AuditSqlResponseSql'
    }

    attribute_map = {
        'sql': 'sql'
    }

    def __init__(self, sql=None):
        r"""AuditSqlResponseSqls

        The model defined in huaweicloud sdk

        :param sql: 
        :type sql: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        
        

        self._sql = None
        self.discriminator = None

        self.sql = sql

    @property
    def sql(self):
        r"""Gets the sql of this AuditSqlResponseSqls.

        :return: The sql of this AuditSqlResponseSqls.
        :rtype: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        return self._sql

    @sql.setter
    def sql(self, sql):
        r"""Sets the sql of this AuditSqlResponseSqls.

        :param sql: The sql of this AuditSqlResponseSqls.
        :type sql: :class:`huaweicloudsdkdbss.v1.AuditSqlResponseSql`
        """
        self._sql = sql

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AuditSqlResponseSqls):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
